#[non_exhaustive]pub enum MessageKind {
Privmsg,
Notice,
Ctcp {
command: String,
},
Tagmsg,
Join,
Part,
Quit,
Kick {
target: String,
},
Nick {
new_nick: String,
},
Topic,
Mode,
}Expand description
What kind of thing happened.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Privmsg
An ordinary message.
Notice
A notice, which by convention a client must not auto-reply to.
Ctcp
A CTCP, carrying the command that was requested.
Tagmsg
A bodiless message that exists only to carry tags.
Join
Someone joined.
Part
Someone left the channel.
Quit
Someone left the network.
Kick
Someone was removed by an operator.
Nick
Someone changed nick.
Topic
The topic changed.
Mode
Modes changed.